#! /bin/sh
####################################################
# Description
# Create SSL certificates and JKS store files for
# Webhook listener for message bus probe 
# based on the FQDN used to connect to probe
####################################################
# Read command line arguments
####################################################
if [ $# -ne 2 ]
then
echo
echo "Usage : `basename $0` [Webhook FQDN] [JAVA_HOME]"
echo
echo "where JAVA_HOME is the path to the required keystore Java"
echo "and FQDN is the fully qualified domain name's for the"
echo "probe host"
exit
fi
####################################################
# Server and Client FQDN
####################################################
WEBHOOKFQDN=$1
JAVA_HOME=${2}
####################################################
# Check java
####################################################
if [ ! -f ${JAVA_HOME}/bin/keytool ]
then
echo "Did not find keytool in : ${JAVA_HOME}/bin"
exit
fi
####################################################
# SSL parameters
####################################################
# Set a common passphrase for everything for now
####################################################
PASSPHRASE="netcool"
MYOU="Netcool"
MYO="IBM"
MYCITY="New York"
MYSTATE="New York"
MYCC="US"
####################################################
export MYOU MYO MYCITY MYSTATE MYCC PASSPHRASE
export WEBHOOKFQDN CLIENTFQDN
####################################################
# Set path to common java
####################################################
PATH=${JAVA_HOME}/bin:$PATH
####################################################
# Clean up old files
####################################################
echo "*** Cleaning up old files"
rm rand cakey.pem careq.pem caroot.cert caroot.srl
rm KeyStore.jks TrustStore.jks
rm webhook.unsigned.cert webhook.signed.cert
####################################################
# Echo out parameters
####################################################
echo "*** Using the following parameters"
echo "Probe FQDN   : $WEBHOOKFQDN"
echo "Passphrase is : $PASSPHRASE"
echo "Type passphrase/password ${PASSPHRASE} when prompted"
echo "Type yes to trust certificates"
echo "Hit return to continue>"
read n
####################################################
# Create ROOT CA
####################################################
echo "*** Create CA Certificate"
RANDFILE=rand
export RANDFILE
openssl req -new -keyout cakey.pem -out careq.pem <<EOF
${MYCC}
${MYSTATE}
${MYCITY}
${MYO}
${MYOU}
${WEBHOOKFQDN}
root@${WEBHOOKFQDN}
${PASSPHRASE}
${MYO}
EOF


openssl x509 -signkey cakey.pem -req -days 3650 -in careq.pem -out caroot.cert -extensions v3_ca

ls -l

echo "*** Creating TrustStore.jks"
keytool -keystore TrustStore.jks -alias ROOTCA -import -file caroot.cert -storepass ${PASSPHRASE}

echo "*** Creating KeyStore.jks"
keytool -keystore KeyStore.jks -alias webhook -validity 3650 -genkey -keyalg RSA \
 -storepass ${PASSPHRASE} \
 -ext SAN=DNS:${WEBHOOKFQDN} <<EOF
${WEBHOOKFQDN}
${MYOU}
${MYO}
${MYCITY}
${MYSTATE}
${MYCC}
yes
${PASSPHRASE}
EOF



keytool -keystore KeyStore.jks -alias webhook \
-certreq -file webhook.unsigned.cert -storepass ${PASSPHRASE}

openssl x509 -req -CA caroot.cert -CAkey cakey.pem -in webhook.unsigned.cert \
-out webhook.signed.cert -days 3650 -CAcreateserial 

keytool -keystore KeyStore.jks -alias ROOTCA -import -file caroot.cert -storepass ${PASSPHRASE}

keytool -keystore KeyStore.jks -alias webhook \
-import -file webhook.signed.cert -storepass ${PASSPHRASE}

echo "*** List results"
echo "ROOTCA:"
keytool -printcert -v -file caroot.cert
echo "KeyStore.jks:"
keytool -list -keystore KeyStore.jks -storepass ${PASSPHRASE}
echo "TrustStore.jks:"
keytool -list -keystore TrustStore.jks -storepass ${PASSPHRASE}

echo "*** Created files"
ls -l

#EOF
